@@ -39,8 +39,6 @@ def attachSettings(settingsDict, enablePaypal=False):
     @param enablePaypal enable pay with paypal or not
     """
 
-    BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
-
     #=========================================================================
     # Django plugins.
 
@@ -105,7 +103,7 @@ def attachSettings(settingsDict, enablePaypal=False):
 
     # Template tags
     ADDING_TEMPLATES_DIRS = [
-        os.path.join(BASE_DIR, 'templates'),
+        os.path.join(settingsDict['BASE_DIR'], 'templates'),
         OSCAR_MAIN_TEMPLATE_DIR,
     ]
     extendTemplateDirs(settingsDict, ADDING_TEMPLATES_DIRS)
